@@ -9,10 +9,7 @@ import operator
 
 from typing import Optional
 
-try:
-    from importlib import metadata  # type: ignore
-except ImportError:
-    import importlib_metadata as metadata  # type: ignore
+import importlib_metadata as metadata
 
 from . import credentials, errors, util
 from .util import properties
@@ -44,6 +41,9 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
     this interface.
     """
 
+    def __init__(self):
+        self.set_properties_from_env()
+
     # @abc.abstractproperty
     def priority(cls):
         """
@@ -94,12 +94,12 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
         )
 
     @abc.abstractmethod
-    def get_password(self, service, username) -> Optional[str]:
+    def get_password(self, service: str, username: str) -> Optional[str]:
         """Get password of the username for the service"""
         return None
 
     @abc.abstractmethod
-    def set_password(self, service, username, password):
+    def set_password(self, service: str, username: str, password: str) -> None:
         """Set password for the username of the service.
 
         If the backend cannot store passwords, raise
@@ -110,7 +110,7 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
     # for backward-compatibility, don't require a backend to implement
     #  delete_password
     # @abc.abstractmethod
-    def delete_password(self, service, username):
+    def delete_password(self, service: str, username: str) -> None:
         """Delete the password for the username of the service.
 
         If the backend cannot delete passwords, raise
@@ -122,8 +122,10 @@ class KeyringBackend(metaclass=KeyringBackendMeta):
     #  get_credential
     # @abc.abstractmethod
     def get_credential(
-        self, service, username
-    ) -> Optional[credentials.SimpleCredential]:
+        self,
+        service: str,
+        username: Optional[str],
+    ) -> Optional[credentials.Credential]:
         """Gets the username and password for the service.
         Returns a Credential instance.
 
@@ -180,21 +182,18 @@ def _load_plugins():
     Locate all setuptools entry points by the name 'keyring backends'
     and initialize them.
     Any third-party library may register an entry point by adding the
-    following to their setup.py::
+    following to their setup.cfg::
 
-        entry_points = {
-            'keyring.backends': [
-                'plugin_name = mylib.mymodule:initialize_func',
-            ],
-        },
+        [options.entry_points]
+        keyring.backends =
+            plugin_name = mylib.mymodule:initialize_func
 
     `plugin_name` can be anything, and is only used to display the name
     of the plugin at initialization time.
 
     `initialize_func` is optional, but will be invoked if callable.
     """
-    entry_points = metadata.entry_points().get('keyring.backends', [])
-    for ep in entry_points:
+    for ep in metadata.entry_points(group='keyring.backends'):
         try:
             log.debug('Loading %s', ep.name)
             init_func = ep.load()
