@@ -1,6 +1,4 @@
-from ..py32compat import abc
-
-__metaclass__ = type
+from collections import abc
 
 
 class ClassProperty(property):
@@ -25,6 +23,7 @@ class ClassProperty(property):
     def __get__(self, cls, owner):
         return self.fget.__get__(None, owner)()
 
+
 # borrowed from jaraco.util.dictlib
 
 
