@@ -1,7 +1,4 @@
-try:
-    from importlib import metadata  # type: ignore
-except ImportError:
-    import importlib_metadata as metadata  # type: ignore
+import importlib_metadata as metadata
 
 from keyring import backend
 
@@ -11,13 +8,14 @@ def test_entry_point():
     Keyring provides exactly one 'keyring' console script
     that's a callable.
     """
-    scripts = dict(metadata.entry_points()['console_scripts'])
-    assert callable(scripts['keyring'].load())
+    matches = metadata.entry_points(group='console_scripts', name='keyring')
+    (script,) = matches
+    assert callable(script.load())
 
 
 def test_missing_metadata(monkeypatch):
     """
     _load_plugins should pass when keyring metadata is missing.
     """
-    monkeypatch.setattr(metadata, 'entry_points', dict)
+    monkeypatch.setattr(metadata, 'entry_points', metadata.EntryPoints().select)
     backend._load_plugins()
